Class: Nutils::Errors::NoRulesFileFound

Inherits:
Nanoc::Errors::NoRulesFileFound
  • Object
show all
Defined in:
lib/nutils/base/errors.rb

Overview

Error that is raised when no partial rules file can be found in any directory provided.

Instance Method Summary collapse

Constructor Details

#initialize(filename) ⇒ NoRulesFileFound

Returns a new instance of NoRulesFileFound.

Parameters:

  • filename (String)

    The file name not found.



10
11
12
# File 'lib/nutils/base/errors.rb', line 10

def initialize(filename)
  super("No file found in any directory provided for #{filename}".make_compatible_with_env)
end